@@ -3,12 +3,13 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2016 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
 namespace Zend\Db\Adapter;
 
+use Interop\Container\ContainerInterface;
 use Zend\ServiceManager\FactoryInterface;
 use Zend\ServiceManager\ServiceLocatorInterface;
 
@@ -17,12 +18,23 @@ class AdapterServiceFactory implements FactoryInterface
     /**
      * Create db adapter service
      *
-     * @param ServiceLocatorInterface $serviceLocator
+     * @param  ContainerInterface $container
      * @return Adapter
      */
-    public function createService(ServiceLocatorInterface $serviceLocator)
+    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
     {
-        $config = $serviceLocator->get('Config');
+        $config = $container->get('config');
         return new Adapter($config['db']);
     }
+
+    /**
+     * Create db adapter service (v2)
+     *
+     * @param ServiceLocatorInterface $container
+     * @return Adapter
+     */
+    public function createService(ServiceLocatorInterface $container)
+    {
+        return $this($container, Adapter::class);
+    }
 }
